@@ -8,7 +8,7 @@ from torch import tensor
 import matplotlib.pyplot as plt
 import matplotlib as mpl
 from dl2050utils.core import listify, camel2snake
-from nn2.etc import *
+from dl2050nn.etc import *
 
 
 def randn(n): return random.randint(0,n)
